@@ -25,18 +25,6 @@ impl Terminals {
         Self(Vec::with_capacity(MAX_K))
     }
 
-    ///
-    /// Creates a new object with maximum k length from another object
-    ///
-    pub fn take_k(k: usize, other: &Self) -> Self {
-        let first_len = other.k_len(k);
-        let mut terminals = Self::new();
-        for elem in other.0.iter().take(first_len) {
-            terminals.0.push(*elem);
-        }
-        terminals
-    }
-
     ///
     /// Creates a new object with maximum k length from another object
     ///
@@ -261,19 +249,6 @@ impl KTuple {
         Self { terminals, k }
     }
 
-    ///
-    /// Creates a new object with maximum k length from another object
-    ///
-    pub fn take_k(k: usize, other: &Self) -> Self {
-        let terminals = Terminals::take_k(k, other.terminals.inner());
-        let terminals = if terminals.is_k_complete(k) {
-            TerminalString::Complete(terminals)
-        } else {
-            TerminalString::Incomplete(terminals)
-        };
-        Self { terminals, k }
-    }
-
     ///
     /// Creates a new object from a slice of other objects
     ///
