@@ -3,7 +3,7 @@ extern crate error_chain;
 
 use parol::conversions::par::render_par_string;
 use parol::errors::*;
-use parol::obtain_cfg_ext;
+use parol::obtain_grammar_config;
 use std::env;
 
 quick_main!(run);
@@ -13,7 +13,7 @@ fn run() -> Result<()> {
     let args: Vec<String> = env::args().collect();
     if args.len() > 1 {
         let file_name = args[1].clone();
-        let grammar_config = obtain_cfg_ext(&file_name, false)?;
+        let grammar_config = obtain_grammar_config(&file_name, false)?;
         println!("{}", render_par_string(&grammar_config, true));
     } else {
         println!("Missing arguments <par-file>!");
