@@ -55,7 +55,7 @@ fn run() -> Result<()> {
 
     let verbose = config.is_present("verbose");
 
-    let mut grammar_config = obtain_cfg_ext(
+    let mut grammar_config = obtain_grammar_config(
         config.value_of("grammar"),
         verbose,
         config.is_present("generate_tree_graph"),
@@ -105,14 +105,8 @@ fn run() -> Result<()> {
 
     let user_type = config.value_of("user_type").unwrap();
 
-    let parser_source = generate_parser_source(
-        &grammar_config,
-        &lexer_source,
-        &lookahead_dfa_s,
-        user_type,
-        user_trait_module_name,
-    )
-    .chain_err(|| "Failed to generate parser source!")?;
+    let parser_source = generate_parser_source(&grammar_config, &lexer_source, &lookahead_dfa_s)
+        .chain_err(|| "Failed to generate parser source!")?;
 
     if let Some(parser_file_out) = config.value_of("parser") {
         fs::write(parser_file_out, parser_source)
@@ -165,7 +159,7 @@ fn generate_tree_layout(
         .chain_err(|| "Failed writing layout")
 }
 
-fn obtain_cfg_ext(
+fn obtain_grammar_config(
     grammar: Option<&str>,
     verbose: bool,
     generate_tree_graph: bool,
